| metals | R Documentation |
A dataset of 165 observations of base metals price indices. It includes point forecasts from 15 predictive models (Bayesian and shrinkage-based). This dataset is based on the research methodology and benchmarks presented in Drachal and Jedrzejewska (2025).
metals
A matrix with 165 rows and 15 columns:
metals[,1:14]: Point forecasts from 14 competing models (including
variations of Bayesian Dynamic Mixture Models (BDMM), Dynamic Model Averaging (DMA),
Time-Varying Parameters (TVP), as well as Bayesian LASSO, Bayesian RIDGE,
Autoregressive (AR1), and Linear Regression).
metals[,15]: HA - Historical Average (Benchmark model).
Monthly World Bank base metals price index (2010 = 100, USD), including aluminium, copper, lead, nickel, tin and zinc, forecasts for the period from 03/2011 to 11/2024.
Drachal, K. (2025). Base metals price index forecasts. figshare. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.6084/m9.figshare.28382480.v1")}
Drachal, K., & Jedrzejewska, J. (2025). Forecasting Base Metals Prices: A Comparison of Various Bayesian-Based Methods. Sinteza 2025, 175–183. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15308/Sinteza-2025-175-183")}
World Bank. (2025). Commodity markets. https://www.worldbank.org/en/research/commodity-markets
data(metals)
head(metals)
plot(metals[, 1], type = "l", main = "Competing Model vs Benchmark")
lines(metals[, ncol(metals)], col = "red", lty = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.